==> modonomicon-1.21.5-fabric-1.117.2-sources.jar: com/klikli_dev/modonomicon/client/BookModel.java <==
/*
 * SPDX-FileCopyrightText: 2023 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.client;

import com.klikli_dev.modonomicon.item.ModonomiconItem;
import com.klikli_dev.modonomicon.registry.ItemRegistry;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Map;
import net.minecraft.class_10439;
import net.minecraft.class_10442;
import net.minecraft.class_10444;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_638;
import net.minecraft.class_811;

public class BookModel implements class_10439 {
    private final class_10439 original;

    public BookModel(class_10439 original) {
        this.original = original;
    }

    public static void replace(Map<class_2960, class_10439> models) {
        models.computeIfPresent(ItemRegistry.MODONOMICON.getId(), (k, oldModel) -> new BookModel(oldModel));
    }


    @Override
    public void method_65584(@NotNull class_10444 renderState, @NotNull class_1799 stack, @NotNull class_10442 itemModelResolver, @NotNull class_811 displayContext, @Nullable class_638 level, @Nullable class_1309 entity, int seed) {
        var book = ModonomiconItem.getBook(stack);
        if (book != null) {
            var itemModel = class_310.method_1551().method_1554().method_65746(book.getModel());
            itemModel.method_65584(renderState, stack, itemModelResolver, displayContext, level, entity, seed);
        } else {
            this.original.method_65584(renderState, stack, itemModelResolver, displayContext, level, entity, seed);
        }
    }
}

==> modonomicon-1.21.10-fabric-1.119.0-sources.jar: com/klikli_dev/modonomicon/client/BookModel.java <==
/*
 * SPDX-FileCopyrightText: 2023 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.client;

import com.klikli_dev.modonomicon.item.ModonomiconItem;
import com.klikli_dev.modonomicon.registry.ItemRegistry;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Map;
import net.minecraft.class_10439;
import net.minecraft.class_10442;
import net.minecraft.class_10444;
import net.minecraft.class_11566;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_638;
import net.minecraft.class_811;

public class BookModel implements class_10439 {
    private final class_10439 original;

    public BookModel(class_10439 original) {
        this.original = original;
    }

    public static void replace(Map<class_2960, class_10439> models) {
        models.computeIfPresent(ItemRegistry.MODONOMICON.getId(), (k, oldModel) -> new BookModel(oldModel));
    }


    @Override
    public void method_65584(@NotNull class_10444 renderState, @NotNull class_1799 stack, @NotNull class_10442 itemModelResolver, @NotNull class_811 displayContext, @Nullable class_638 level, @Nullable class_11566 owner, int seed) {
        var book = ModonomiconItem.getBook(stack);
        if (book != null) {
            var itemModel = class_310.method_1551().method_1554().method_65746(book.getModel());
            itemModel.method_65584(renderState, stack, itemModelResolver, displayContext, level, owner, seed);
        } else {
            this.original.method_65584(renderState, stack, itemModelResolver, displayContext, level, owner, seed);
        }
    }
}
